# AUTOGENERATED! DO NOT EDIT! File to edit: ../00_core.ipynb.

# %% auto 0
__all__ = ['minus_one', 'add_one']

# %% ../00_core.ipynb 3
from fastcore.utils import *

# %% ../00_core.ipynb 5
def minus_one(): pass

# %% ../00_core.ipynb 7
def add_one(x): return x + 1
