# AUTOGENERATED! DO NOT EDIT! File to edit: ../01_activations.ipynb.

# %% auto 0
__all__ = ['activation']

# %% ../01_activations.ipynb 3
from fastcore.utils import *

# %% ../01_activations.ipynb 5
#def foo(): pass

# %% ../01_activations.ipynb 7
def activation(
        x: int # number only
    ):
    return x + 10
